@@ -83,8 +83,7 @@ fn main() -> tract_core::anyhow::Result<()> {
         .arg(arg!([model] "Sets the model to use"))
         .arg(arg!(-f --format [format]
                   "Hint the model format ('kaldi', 'onnx', 'nnef' or 'tf') instead of guess from extension."))
-
-        .arg(arg!(-i --input [input] ...
+        .arg(Arg::new("input").long("input").short('i').multiple_occurrences(true).takes_value(true).long_help(
                   "Set input shape and type (@file.pb or @file.npz:thing.npy or 3x4xi32)."))
 
         .arg(arg!(--"const-input" [const_input] ... "Treat input as a Const (by name), retaining its value."))
@@ -96,6 +95,7 @@ fn main() -> tract_core::anyhow::Result<()> {
         .arg(arg!(--"kaldi-right-context" [frames] "Add lines of right context to input (dupping last time frame)"))
 
         .arg(arg!(--"onnx-test-data-set" [data_set] "Use onnx-test data-set as input (expect test_data_set_N dir with input_X.pb, etc. inside)"))
+        .arg(arg!(--"onnx-ignore-output-shapes" "Ignore output shapes from model (workaround for pytorch export bug with mask axes)"))
 
         .arg(arg!(--"input-node" [node] ... "Override input nodes names (auto-detects otherwise)."))
         .arg(arg!(--"output-node" [node] ... "Override output nodes name (auto-detects otherwise)."))
